/* ■■■■■■■■■■■■■ ARMOSY-2 Example ■■■■■■■■■■■■

Display of temperature sensor DS18B20 on the LCD

Hardware: ARMOSY-2
Version HW: 2.12
Create: 22.04.2016

   ■■■■■■■■■■■■■ JUMPER ARMOSY PWR ■■■■■■■■■■■■
S12 - ON (1 WIRE)
S6 - ON (+3.3V)
   
   ■■■■■■■■■■■■■ CONNECTION TERMINATOR ■■■■■■■■■■■■
62 - DS18B20 (GND)
61 - DS18B20 (VCC)
60 - DS18B20 (1W)

*/

// ■ LIBRARY

#include <UTFT.h>
#include <OneWire.h> 
#include <DallasTemperature.h>  

// ■ DECLARATIONS

UTFT  myGLCD(ITDB24,38,39,40,41);    // RS, WR, CS, REST
extern uint8_t BigFont[];            // UTFT Fonds

#define DS18B20 5                    // Pin 1W 
OneWire ourWire(DS18B20);            
DallasTemperature sensors(&ourWire);
char sensorPrintout[1];             // Char array to print to the screen
float TMP;                          // Temperature     

// ■■■■■■■■■■■■■ SETUP ■■■■■■■■■■■■

void setup()
{

// ■ TOUCH, UTFT

  myGLCD.InitLCD();               // Initialization LCD              
  myGLCD.clrScr();                // Clear Screen
  myGLCD.fillScr(VGA_WHITE);      // VGA Background Transparency
  myGLCD.setColor(0, 0, 0);       // Black Fonds
  myGLCD.setBackColor(255, 255, 255); // White Background
  myGLCD.setFont(BigFont);        // Select Font 

// ■ HEADER  

  myGLCD.print("ARMOSY2 - SW0002", CENTER, 10);             
  myGLCD.print("www.hwpro.cz", CENTER, 220);     
  
// ■ 1 WIRE  
  sensors.begin();                 
  sensors.setResolution(10);        // Resolution 9-12 bit 
}


// ■■■■■■■■■■■■■ MAIN ■■■■■■■■■■■■

void loop()

{
   myGLCD.print("Temperature", CENTER, 100); // Text, position x, position y 
   sensors.requestTemperatures();   // Send the command to get temperatures.
   String TMP = String(sensors.getTempCByIndex(0)); // Convert String Sensor 0
   TMP.toCharArray(sensorPrintout, 6);    // Convert The Reading To a Char Array, Field
   myGLCD.print(sensorPrintout, CENTER, 120); // Print Value Temperature
   myGLCD.print("C", 200, 120); 
}

